function getExtension(filename) {
  return filename.substring(filename.lastIndexOf('.') + 1, filename.length) || filename;
}

var images = [];
var currentImage = 0;

function getTxtName(filename) {
  return filename.substr(0, filename.lastIndexOf('.') + 1) + "txt";
}

async function loadImage(imageFile) {
  // clear old
  $("#imgHolder").html("");


  // just gets the files extension, either jpg or png
  let txtFile = getTxtName(imageFile);
  let ext = getExtension(imageFile);

  imgData = await Neutralino.filesystem.readBinaryFile(imageFile);

  var base64 = btoa(
    new Uint8Array(imgData).reduce((data, byte) => data + String.fromCharCode(byte), '')
  );
  var img = document.createElement('img');
  img.src = 'data:image/' + ext + '+;base64,' + base64;

  $("#imgHolder").append(img);

  currentImage = images.indexOf(imageFile);

  // unselect, then select
  $("#imageList").children().removeClass("selectedOption");
  $("#imageList").children("div[data-turl='imageFile']").addClass("selectedOption");

}

$(document).ready(function () {
  $("#workArea").hide();

  $("#loadDir").click(function () {
    loadDirectory();
  });

  $("#saveAndNext").click(function () {
    advanceImg();
  });

  $("#addToAll").click(function () {
    addToAll();
  });


  $("#imageList").on("click", ".aImg", function () {

    let clickedImg = $(this).data("turl");
    loadImg(clickedImg);
    console.log(clickedImg);

  });

});


async function loadImg(newImage) {
  // save text
  let text = $("#description").val();
  let txtFile = getTxtName(images[currentImage]);

  await Neutralino.filesystem.writeFile(txtFile, text);


  loadImage(newImage);
  currentImage = images.indexOf(newImage);

  let newTxtFile = getTxtName(newImage);
  let descrip = await Neutralino.filesystem.readFile(newTxtFile);

  $("#description").val(descrip);
  $("#imageList").children().removeClass("select");
  $("#imageList").children('*[data-turl="' + images[currentImage] + '"]').addClass("select");


}

async function advanceImg() {

  nextImage = currentImage + 1;

  if (nextImage >= images.length) {
    nextImage = 0;
  }

  let newImage = images[nextImage];
  loadImg(newImage);

}

async function addToAll() {
  
  let toAdd = $("#allDescription").val();
  let eTxt = "";
  
  for(let i=0;i<images.length;i++){
    eTxt = getTxtName(images[i]);
    Neutralino.filesystem.appendFile(eTxt, toAdd);    
  }
  
  // also
  $("#description").val($("#description").val() + toAdd);
  
  $("#allDescription").val("");
  alert("Added to all: " + toAdd);

}

async function loadDirectory() {


  let inDir = await Neutralino.os.showFolderDialog('Select an image-filled directory', {});

  //let inDir = $("#inputDirectory").val();

  try {
    let stats = await Neutralino.filesystem.getStats(inDir);
    if (!stats['isDirectory']) {
      alert("Please put a directory in the input.");
      return;
    }

  } catch (error) {
    alert("Please put a directory in the input.")
    return;
  }

  let entries = await Neutralino.filesystem.readDirectory(inDir);
  //console.log(entries);
  // foreach entry...

  let imgListHtml = "";
  let imgCount = 0;

  let tmpImages = [];

  for (let i = 0; i < entries.length; i++) {
    //console.log(getExtension(entries[i]['entry']) + " " + ".png");



    if ((getExtension(entries[i]['entry']) === "jpg") || (getExtension(entries[i]['entry']) === "png")) {

      // add it to images 
      let imgUrl = inDir + "/" + entries[i]['entry'];
      //console.log("Url: " + imgUrl);
      tmpImages.push(imgUrl);
      imgCount++;
      imgListHtml += "<div class='aImg' data-turl='" + imgUrl + "'>Image " + imgCount + "</div>";
    }
  }


  // if no images, don't continue.
  if (tmpImages.length == 0) {
    return;
  }

  images = tmpImages;

  // make needed txt files
  for (let i = 0; i < images.length; i++) {
    let imgName = images[i];
    let imgBaseName = getTxtName(imgName);
    await Neutralino.filesystem.appendFile(imgBaseName, '');


  }


  // now, load the first image
  currentImage = 0;
  loadImage(images[currentImage]);




  $("#imageList").html(imgListHtml);

  let descrip = await Neutralino.filesystem.readFile(getTxtName(images[currentImage]));

  $("#description").val(descrip);

  $("#imageList").children().removeClass("select");
  $("#imageList").children('*[data-turl="' + images[currentImage] + '"]').addClass("select");



  $("#currentDir").html(inDir);
  $("#helpArea").hide();
  $("#workArea").show();

}


function onTrayMenuItemClicked(event) {
  switch (event.detail.id) {
    case "QUIT":
      Neutralino.app.exit();
      break;
  }
}

function onWindowClose() {
  Neutralino.app.exit();
}

Neutralino.init();

//Neutralino.events.on("trayMenuItemClicked", onTrayMenuItemClicked);
Neutralino.events.on("windowClose", onWindowClose);
